@@ -2,7 +2,7 @@
 
 use std::path::Path;
 
-use tracing::{debug, warn};
+use tracing::debug;
 
 use crate::build_tools::{cargo, elm, mix, npm, BuildTool, BuildToolProbe};
 
@@ -10,67 +10,33 @@ pub struct BuildToolManager {
     probes: Vec<Box<dyn BuildToolProbe>>,
 }
 
-#[cfg(test)]
-#[allow(clippy::derivable_impls)]
 impl Default for BuildToolManager {
     fn default() -> Self {
+        let mut build_tool_manager = Self::new();
+
+        cargo::register(&mut build_tool_manager);
+        elm::register(&mut build_tool_manager);
+        mix::register(&mut build_tool_manager);
+        npm::register(&mut build_tool_manager);
+
+        // TODO: Activate those as soon as the tests are there:
+        // gradle::register(&mut build_tool_manager);
+        // maven::register(&mut build_tool_manager);
+
+        build_tool_manager
+    }
+}
+
+impl BuildToolManager {
+    /// Create a new instance with no probes attached.
+    ///
+    /// To get an instance with default probes, use `BuildToolManager::default`.
+    pub fn new() -> Self {
         Self {
             probes: Default::default(),
         }
     }
-}
 
-impl BuildToolManager {
-    pub fn with_readonly_probes() -> Self {
-        let mut build_tool_manager = Self {
-            probes: Default::default(),
-        };
-
-        if let Err(e) = cargo::register(&mut build_tool_manager, true) {
-            warn!("Cargo disabled: {e}");
-        }
-
-        elm::register(&mut build_tool_manager);
-
-        if let Err(e) = mix::register(&mut build_tool_manager, true) {
-            warn!("Mix disabled: {e}");
-        }
-
-        npm::register(&mut build_tool_manager);
-
-        // TODO: Activate those as soon as the tests are there:
-        // gradle::register(&mut build_tool_manager);
-        // maven::register(&mut build_tool_manager);
-
-        build_tool_manager
-    }
-
-    pub fn with_readwrite_probes() -> Self {
-        let mut build_tool_manager = Self {
-            probes: Default::default(),
-        };
-
-        if let Err(e) = cargo::register(&mut build_tool_manager, false) {
-            warn!("Cargo disabled: {e}");
-        }
-
-        elm::register(&mut build_tool_manager);
-
-        if let Err(e) = mix::register(&mut build_tool_manager, false) {
-            warn!("Mix disabled: {e}");
-        }
-
-        npm::register(&mut build_tool_manager);
-
-        // TODO: Activate those as soon as the tests are there:
-        // gradle::register(&mut build_tool_manager);
-        // maven::register(&mut build_tool_manager);
-
-        build_tool_manager
-    }
-}
-
-impl BuildToolManager {
     /// Add a build-tool probe.
     ///
     /// Not idempotent - multiple calls will cause the probe to be invoked more
