@@ -1,7 +1,6 @@
-use super::{BuildStatus, BuildTool, BuildToolProbe};
-use crate::{build_tool_manager::BuildToolManager, fs::dir_size};
+use super::{remove_dirs, status_from_dirs, BuildStatus, BuildTool, BuildToolProbe};
+use crate::{build_tool_manager::BuildToolManager};
 use std::{
-    fs,
     path::{Path, PathBuf},
 };
 
@@ -36,47 +35,16 @@ pub struct Npm {
     path: PathBuf,
 }
 
-static NODE_MODULES: &str = "node_modules";
-
-impl Npm {
-    fn dir(&self, name: &str) -> Option<PathBuf> {
-        let dir = self.path.join(name);
-        if dir.is_dir() {
-            Some(dir)
-        } else {
-            None
-        }
-    }
-}
+static EPHEMERAL_DIRS: &[&str] = &["node_modules"];
 
 impl BuildTool for Npm {
     fn clean_project(&mut self, dry_run: bool) -> anyhow::Result<()> {
-        if let Some(node_modules) = self.dir(NODE_MODULES) {
-            if dry_run {
-                println!("{}: rm -r {}", self.path.display(), node_modules.display());
-            } else {
-                fs::remove_dir_all(node_modules)?;
-            }
-        }
-
         // TODO: also delete build directory, depending on the language(s) used
-
-        Ok(())
+        remove_dirs(&self.path, EPHEMERAL_DIRS, dry_run)
     }
 
     fn status(&self) -> anyhow::Result<BuildStatus> {
-        let size: u64 = [NODE_MODULES]
-            .iter()
-            .filter_map(|x| self.dir(x))
-            .map(|dir| dir_size(&dir))
-            .sum();
-
-        let status = match size {
-            0 => BuildStatus::Clean,
-            freeable_bytes => BuildStatus::Built { freeable_bytes },
-        };
-
-        Ok(status)
+        status_from_dirs(&self.path, EPHEMERAL_DIRS)
     }
 }
 
