@@ -2,7 +2,9 @@
 
 use serde::{Deserialize, Serialize};
 
-use crate::{vcs::VersionControlSystem, Project};
+use crate::Project;
+
+use super::vcs::VersionControlSystem;
 
 #[derive(Debug, Serialize, Deserialize)]
 pub struct ProjectDto {
